<?php
/** Araucanian (Mapudungun)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Clerc
 * @author Fiestoforo
 * @author Kaniw
 * @author Lin linao
 * @author Poquil
 * @author Remember the dot
 */

$fallback = 'es';

$messages = array(
# User preference toggles
'tog-underline'        => 'Miñcewirilpe lasun',
'tog-justify'          => 'Xvrvmpe cijkantvkun',
'tog-showtoolbar'      => 'Pengelün kümeelün ñi chemkün (JavaScript duamyengey)',
'tog-editondblclick'   => 'Wirin pakina epu klik mew (JavaScript)',
'tog-rememberpassword' => 'Amulen tañi nülküwküleael tüfa mew (alürumechi $1 {{PLURAL:$1 antü}})',

'underline-always' => 'Rumel',
'underline-never'  => 'Turpu',

# Dates
'sunday'        => 'Domingku',
'monday'        => 'Lune',
'tuesday'       => 'Marte',
'wednesday'     => 'Mierkole',
'thursday'      => 'Kuefe',
'friday'        => 'Fierne',
'saturday'      => 'Safado',
'sun'           => 'dom',
'mon'           => 'lun',
'tue'           => 'mar',
'wed'           => 'mie',
'thu'           => 'kue',
'fri'           => 'fie',
'sat'           => 'saf',
'january'       => 'eneru küyeṉ',
'february'      => 'fewreru küyeṉ',
'march'         => 'marsu küyeṉ',
'april'         => 'afril küyeṉ',
'may_long'      => 'mayu küyeṉ',
'june'          => 'kuniu küyeṉ',
'july'          => 'kuliu küyeṉ',
'august'        => 'akostu küyeṉ',
'september'     => 'setiempüre küyeṉ',
'october'       => 'oktufüre küyeṉ',
'november'      => 'nofiempüre küyeṉ',
'december'      => 'disiempüre küyeṉ',
'january-gen'   => 'eneru küyeṉ',
'february-gen'  => 'fewreru küyeṉ',
'march-gen'     => 'marsu küyeṉ',
'april-gen'     => 'afril küyeṉ',
'may-gen'       => 'mayu küyeṉ',
'june-gen'      => 'kuniu küyeṉ',
'july-gen'      => 'kuliu küyeṉ',
'august-gen'    => 'akostu küyeṉ',
'september-gen' => 'setiempüre küyeṉ',
'october-gen'   => 'oktufüre küyeṉ',
'november-gen'  => 'nofiempüre küyeṉ',
'december-gen'  => 'disiempüre küyeṉ',
'jan'           => 'eneru',
'feb'           => 'fewreru',
'mar'           => 'marsu',
'apr'           => 'afril',
'may'           => 'mayu',
'jun'           => 'kuniu',
'jul'           => 'kuliu',
'aug'           => 'akostu',
'sep'           => 'setiempüre',
'oct'           => 'oktufüre',
'nov'           => 'nofiempüre',
'dec'           => 'disiempüre',

# Categories related messages
'pagecategories'         => '{{PLURAL:$1|Trokiñ}}',
'category_header'        => 'Wülngiñ trokiñ "$1"',
'subcategories'          => 'Minche trokiñ',
'category-media-header'  => 'Fill dungu (adentun, dungun, fidew) "$1" trokiñ mew',
'category-empty'         => "''Tüfachi trokiñ fewla nielay wülngiñ kam fill dungu no rume.''",
'hidden-categories'      => '{{PLURAL:$1|Ellkalelu trokiñ wülgiñ}}',
'category-subcat-count'  => '{{PLURAL:$2|Tüfachi trokiñ niey kiñe minchetrokiñ müten.|Tüfachi trokiñ niey {{PLURAL:$1 minchetrokiñ}}, $2 mew.}}',
'category-article-count' => '{{PLURAL:$2|Tüfachi trokiñ niey tüfachi wülngiñ.|Tüfachi {{PLURAL:$1wülngiñ}} tüfachi trokiñ mew, kom $2 mew.}}',
'category-file-count'    => '{{PLURAL:$2|Tüfachi trokiñ niey tüfachi wülngiñ müten.|Tüfachi {{PLURAL:$1 eltukawün}} müley tüfachi trokiñ mew, kom $2 mew.}}',
'listingcontinuesabbrev' => 'ramt.',
'index-category'         => 'Wülngiñ mülelu wif mew',
'noindex-category'       => 'Wülngiñ mülenolu wif mew',

'about'         => 'Ñi dungu',
'article'       => 'Trokiñdungu wülngiñ',
'newwindow'     => '(Nülay we konkintuwe mew)',
'cancel'        => 'Katrüntukun',
'moredotdotdot' => 'Doy...',
'mypage'        => 'tañi nütramkawe',
'mytalk'        => 'Tañi nütramkawe',
'anontalk'      => 'Tüfachi IP ñi nütramkawe',
'navigation'    => 'Miyawün',
'and'           => '&#32;ka',

# Cologne Blue skin
'qbfind'         => 'Kintupe',
'qbedit'         => 'Pepikape',
'qbpageinfo'     => 'Trokiñdungu',
'qbmyoptions'    => 'tañi nütramkawe',
'qbspecialpages' => 'Kangelu',
'faq'            => 'Rumelfemkelu ramtun',
'faqpage'        => 'Project:FAQ',

# Vector skin
'vector-action-addsection' => 'Püñamtun dungu',
'vector-action-delete'     => 'Liftun',
'vector-action-move'       => 'Wiñamün',
'vector-action-protect'    => 'Nürüfkünun',
'vector-action-undelete'   => 'Wüñoñamümün',
'vector-action-unprotect'  => 'Kalekünun Nürüfkünun',
'vector-view-create'       => 'Dewman',
'vector-view-edit'         => 'Kümeelün',
'vector-view-history'      => 'Pengelün rupañmael',
'vector-view-view'         => 'Chillkatun',
'vector-view-viewsource'   => 'Kimam chew küpan chi wirin',
'actions'                  => 'Femün',
'namespaces'               => 'Üytun ñi wellin',
'variants'                 => 'Kaleyelu',

'errorpagetitle'    => 'Welulkan',
'returnto'          => 'Amutun $1 püle.',
'tagline'           => '{{SITENAME}} mew',
'help'              => 'Kelluagen',
'search'            => 'Kintun',
'searchbutton'      => 'Kintun',
'go'                => 'Amupe',
'searcharticle'     => 'Amupe',
'history'           => 'Pünon',
'history_short'     => 'Rupañmael',
'printableversion'  => 'Wirinentuam ñi ad',
'permalink'         => 'Mülekalelu lasun',
'print'             => 'Wirinentupe',
'view'              => 'Pen',
'edit'              => 'Kümeelün',
'create'            => 'Dewman',
'editthispage'      => 'Wirin tüfachi wülngiñ',
'create-this-page'  => 'Llitun tüfachi pakina',
'delete'            => 'Liftun',
'deletethispage'    => 'Ñamümün tüfachi pakina',
'viewdeleted_short' => 'Pen {{PLURAL:$1|kiñe wirin ñamümgün|$1 wirin ñamümün}}',
'protect'           => 'Elulan ñi wiriael',
'protect_change'    => 'kalekünun',
'protectthispage'   => 'Nürüfkünun tüfachi wülngiñ',
'unprotect'         => 'Kalekünun kuñiwtun',
'newpage'           => 'We wülngiñ',
'talkpage'          => 'Nütramkafinge tüfachi pakina',
'talkpagelinktext'  => 'Nütramkan',
'specialpage'       => 'Kangelu',
'personaltools'     => 'Kidungechi küdawpeyüm',
'articlepage'       => 'Adkintun trokiñdungu wülngiñ',
'talk'              => 'Nütramkawün',
'views'             => 'Adngelün',
'toolbox'           => 'Küdawpeyüm',
'userpage'          => 'Adkintun kellufe ñi wülngiñ',
'projectpage'       => 'Adkintun zeumanzugu wülngiñ',
'imagepage'         => 'Adkintun ad wülngiñ',
'mediawikipage'     => 'Adkintun werkün wülngiñ',
'templatepage'      => 'Adkintun adtükupeyüm wülngiñ',
'viewhelppage'      => 'Adkintun kellu wülngiñ',
'categorypage'      => 'Adkintun trokiñ wülngiñ',
'viewtalkpage'      => 'Pen ti nütramkawe',
'otherlanguages'    => 'Kake dungun',
'redirectedfrom'    => '(Wüñogünegey $1 mew)',
'redirectpagesub'   => 'Wüñongünenielu wülngiñ',
'lastmodifiedat'    => 'Tüfachi wülngiñ kalekünungey inagechi rupa, $1, $2 mew.',
'protectedpage'     => 'Nürüfkünungelu wülngiñ',
'jumpto'            => 'Amulün:',
'jumptonavigation'  => 'miyawün',
'jumptosearch'      => 'kintun',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => '{{SITENAME}} ñi dungu',
'aboutpage'            => 'Project:Dungu',
'copyrightpage'        => '{{ns:project}}:Norkülelu ñi ngenngelu ñi deumakelu',
'currentevents'        => 'Fantepu chemkün',
'currentevents-url'    => 'Project:Fantepu chemkün',
'disclaimers'          => 'Tukuldungun ñi pin ley',
'disclaimerpage'       => 'Project:Katrütuwün ñi llowdüngun',
'edithelp'             => 'Kellü wirin',
'edithelppage'         => 'Help:Chum wiringekey pakina',
'helppage'             => 'Help:Trokiñdungu',
'mainpage'             => 'Ñidol Wülngiñ',
'mainpage-description' => 'Ñidol Wülngiñ',
'portal'               => 'Lofche ñi wülngiñ',
'portal-url'           => 'Project:Lofche ñi wülngiñ',
'privacy'              => 'Kuñiwtun kimel dungu',
'privacypage'          => 'Project:Kuñiwtun kimel dungu',

'ok'                      => 'Feley',
'retrievedfrom'           => 'Nentungey "$1" mew',
'youhavenewmessages'      => 'Nieymi $1 ($2).',
'newmessageslink'         => 'weke werkün',
'newmessagesdifflink'     => 'we kalekünun',
'youhavenewmessagesmulti' => 'Nieymi we yefalzugu $1 mew.',
'editsection'             => 'Wirin',
'editold'                 => 'kümeelün',
'viewsourceold'           => 'Kimam chew küpan chi wirin',
'editlink'                => 'kümeelün',
'viewsourcelink'          => 'kimam chew küpan chi wirin',
'editsectionhint'         => 'Kümeelan katrüntuku: $1',
'toc'                     => 'Trokiñdungu',
'showtoc'                 => 'pegelpe',
'hidetoc'                 => 'ellkangepe',
'viewdeleted'             => 'Küpaadkintuymi $1 am?',
'restorelink'             => '{{PLURAL:$1|kiñe wirin ñamümgün|$1 wirin ñamümün}}',
'site-atom-feed'          => '$1 ñi Atom ñi amuldungu',
'page-atom-feed'          => '$1 ñi Atom ñi amuldungu',
'red-link-title'          => '$1 (ngelay tichi adtapül)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Wülngiñ',
'nstab-user'      => 'Kellufe',
'nstab-special'   => 'Wichu wülngiñ',
'nstab-project'   => 'Deumandungu wülngiñ',
'nstab-image'     => 'Eltukawün',
'nstab-mediawiki' => 'Yefalzugu',
'nstab-template'  => 'Adtükupeyüm',
'nstab-help'      => 'Kelluwe',
'nstab-category'  => 'Trokiñ',

# General errors
'error'              => 'Welulkan',
'missing-article'    => 'Feychi ngülümdunguwe kintulay feychi wülngiñ ñi wirin, welu nienuafulu. Ñi üy ta "$1" $2.

Chi kiñe rakizuamün ta pünefalkülenuchi kalelu kam nülkükawlelu liftungepelu wülngiñ ñi rupañmael.

Femnuale, welulkafuy feychi küzauwe. Feypimi tüfachi dungu kiñe [[Special:ListUsers/sysop|ngünefe]]. Wirituymi feychi URL.',
'missingarticle-rev' => '(malün ñi rakin: $1)',
'filedeleteerror'    => 'Pepiñamümüngelay "$1".',
'filenotfound'       => 'Pepipelafuy "$1".',
'badtitle'           => 'Nornongey ta üy',
'badtitletext'       => 'Tüfachi wülngiñ ñi üy kümelay, welliley kam niey weda lasun nülkükawlelu kake dungun kam kake wiki wülngiñ ñi üy.
Nieafuy falinochi wirin püñamtuam wülngiñ ñi üy.',
'viewsource'         => 'Kimam chew küpan chi wirin',

# Login and logout pages
'yourname'                => 'Tami üy',
'yourpassword'            => 'Tami kondungu',
'yourpasswordagain'       => 'Rüf feypinge nülawe:',
'remembermypassword'      => 'Amulen tañi nülküwküleael tüfa mew (alürumechi $1 {{PLURAL:$1 antü}})',
'login'                   => 'Konkülen',
'nav-login-createaccount' => 'konkülen/dewman konün',
'loginprompt'             => 'Müley "Cookies" ñi püneleael wirintukuwam {{SITENAME}} mew.',
'userlogin'               => 'Konkülen/dewman konün',
'userloginnocreate'       => 'Konün',
'logout'                  => 'Tripan',
'userlogout'              => 'Tripan',
'notloggedin'             => 'Petu konlaymi.',
'nologin'                 => 'Nielaymi kiñe konün? $1.',
'nologinlink'             => 'Dewmafinge konün',
'createaccount'           => 'Dewmafinge konün',
'gotaccount'              => 'Dew nieymi konün? $1.',
'gotaccountlink'          => 'Konün',
'userlogin-resetlink'     => 'Ngoyüniengetuymi chumngechi konün?',
'createaccountreason'     => 'Dungu:',
'mailmypassword'          => 'Amulün we nülawe werküwe mew',
'loginlanguagelabel'      => 'Cezugun: $1',

# Change password dialog
'resetpass-submit-cancel' => 'Katrüntukun',

# Edit page toolbar
'bold_sample'     => 'Kurükünualu wirin',
'bold_tip'        => 'Kurükünualu wirin',
'italic_sample'   => 'Küllüke wirin',
'italic_tip'      => 'Küllüke wirin',
'link_sample'     => 'Lasun ñi üy',
'link_tip'        => 'Punwi lasun',
'extlink_sample'  => 'http://www.example.com Lasun ñi üy',
'extlink_tip'     => 'Kamapu lasun (Ngüneduamimi: wüne konkülekey "http://")',
'headline_sample' => 'Lonkolelu wirin',
'headline_tip'    => 'Trürün 2 ñi lonkolelu wirin',
'nowiki_sample'   => 'Üchaftukun ngenochumngen reke chi wirin tüfa mew.',
'nowiki_tip'      => 'Kimfanuel wiki ñi chumkünuwe',
'image_tip'       => 'Üchaftukülechi eltukawün',
'media_tip'       => 'Eltukawün lasun',
'sig_tip'         => 'Tami wirintukun üy ka antü/ora',
'hr_tip'          => 'Kakül wif (Pünengelayafuy rumel)',

# Edit pages
'summary'                          => 'Pichi trokiñündungu:',
'subject'                          => 'Dungu/üy:',
'minoredit'                        => 'Tüfachi ta kiñe pichi wirin',
'watchthis'                        => 'Llaytun tüfachi pakina',
'savearticle'                      => 'Eltukawün wülngiñ',
'preview'                          => 'Pen chum müley',
'showpreview'                      => 'Pen chum müley',
'showdiff'                         => 'Adkintun kalekünun',
'anoneditwarning'                  => "'''Ngüneltun:''' Konkülelaymi. 
Tami chew küpan (IP) chillkatugeay wülngiñ ñi wirin kuyfidungu.",
'loginreqlink'                     => 'Koni',
'newarticle'                       => '(We)',
'newarticletext'                   => 'Ngelay wirin tüfachi wülngiñ mew. 
Pepillituam tüfachi wülngiñ, wirintuaymi nagpüle (pen [[{{MediaWiki:Helppage}}|kellu wülngiñ]] nieael doy kimdungu).
Welule tami küpan, wiñotunge rupachi wülngiñ.',
'noarticletext'                    => 'Iney no rume wirilay tüfachi wülngiñ mew. Eymi [[Special:Search/{{PAGENAME}}|pepikintuymi tüfachi üy]] kake wülngiñ mew,
<span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} kintuymi koneltuyelelu wirintukun],
kam [{{fullurl:{{FULLPAGENAME}}|action=edit}} kümeelaymi tüfachi wülngiñ]</span>.',
'noarticletext-nopermission'       => 'Iney no rume wirilay tüfachi wülngiñ mew. 
Eymi [[Special:Search/{{PAGENAME}}|pepikintuymi tüfachi üy]] kake wülngiñ mew,
kam <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} kintuymi koneltuyelelu wirintukun]</span>.',
'previewnote'                      => "'''Ngüneduamimi tüfachi wüne pen petu eltukawam!'''
Eltukawlelay feychi kalekünun!",
'editing'                          => 'Kümeelngey $1',
'editingsection'                   => 'Wirin $1 (Dungu)',
'editingcomment'                   => 'Wirin $1 (we dungu)',
'yourtext'                         => 'Tami wirin',
'templatesused'                    => '{{PLURAL:$1 adtükupeyüm}} pünelelu tüfa mew:',
'template-protected'               => '(nürüfkünulu)',
'template-semiprotected'           => '(ella nürüfkünungey)',
'hiddencategories'                 => 'Tüfachi wülngiñ koneltuy {{PLURAL:$1 ellkan trokiñ}}:',
'permissionserrorstext-withaction' => 'Nielaymi koneltun femael: $2. Tüfachi {{PLURAL:$1 dungu}} mew:',
'recreate-moveddeleted-warn'       => "'''Ngüneltun: wüñodewmafimi kiñe wülngiñ ta kuyfi liftungey.'''

Müley mi ngüneduamael petu mi amuleal.
Nagpüle wirintukuy chumngely tüfachi wülngiñ liftungey kam nengümngey.",
'moveddeleted-notice'              => 'Liftungey tüfachi wülngiñ. Nagpüle wirintukuy chumngelu tüfachi wülngiñ liftungey kam nengümngey.',

# Parser/template warnings
'post-expand-template-inclusion-warning'  => "'''Ngüneltun:''' Adtükupeyüm rume al'üy. Kiñeke aztükupeyüm nentutungeay.",
'post-expand-template-inclusion-category' => 'Tüfachi wülngiñ rume niey adtükupeyüm',
'post-expand-template-argument-warning'   => "'''Ngüneltun:''' Tüfa mew, kiñe adtükupeyüm ta rume al'un ñi chumtengen.
Rulpakünuy feychi kangelkülelu dungu.",
'post-expand-template-argument-category'  => 'Wülngiñ nielu ayikenon adtükupeyüm',

# History pages
'viewpagelogs'           => 'Pen tüfachi wülngiñ ñi wirintukun',
'currentrev-asof'        => 'Rupalu malün $1 mew',
'revisionasof'           => 'Malün $1 mew',
'revision-info'          => 'Malün $1 mew, $2',
'previousrevision'       => '← Rupachi malün',
'nextrevision'           => 'Kangelu malün →',
'currentrevisionlink'    => 'Fantepu malün',
'cur'                    => 'fewla',
'last'                   => 'rupa',
'page_first'             => 'wünen',
'histlegend'             => "Kalelu wirin ñi dullin: dullintunge trürümüam malün. Trañmange \"kon\" Tekla kam miñche foton minche mew.<br />
Üy: '''({{int:cur}})''' = Trürümün doy we malün, '''({{int:last}})''' = trürümün rupachi malün, '''{{int:minoreditletter}}''' = pichi wirin.",
'history-fieldset-title' => 'Kintun pünon mew',
'history-show-deleted'   => 'Liftungepelu malün müten',
'histfirst'              => 'Wüne',
'histlast'               => 'Doy we',
'historyempty'           => '(welli)',

# Revision feed
'history-feed-item-nocomment' => '$1 $2 mew',

# Revision deletion
'rev-delundel'               => 'pengelün/ellkan',
'rev-showdeleted'            => 'pegelpe',
'revdelete-show-file-submit' => 'May',
'revdel-restore'             => 'kalekünun pengengen',
'revdel-restore-deleted'     => 'liftugepelu malün',
'revdel-restore-visible'     => 'pengengekelu malün',
'pagehist'                   => 'pünon pakina',
'deletedhist'                => 'Ñamümüngelu pünon',
'revdelete-edit-reasonlist'  => 'Wirin dungu ñamümgün mew',

# History merging
'mergehistory-reason' => 'Dungu:',

# Merge log
'revertmerge' => 'Wüñoeltun nülkün',

# Diffs
'history-title'           => 'Kuyfi malün "$1" mew',
'difference'              => '(Trürümün epu malün engu)',
'lineno'                  => 'Wif $1:',
'compareselectedversions' => 'Trürümün dullinngelu malün',
'editundo'                => 'wüñoeltun',
'diff-multi'              => '(Pengelngelay {{PLURAL:$1 trürümün epu malün engu}} ta dewmafi {{PLURAL:$2|kiñe kellufe|$2 pu kellufe}})',

# Search results
'searchresults'                    => 'Tripalu chi kintun mew',
'searchresults-title'              => 'Tripalu chi $1 ñi kintun mew',
'prevn'                            => 'rupachi {{PLURAL:$1|$1}}',
'nextn'                            => 'kangelu {{PLURAL:$1|$1}}',
'prevn-title'                      => 'Rupachi {{PLURAL:$1|tripalu}}',
'nextn-title'                      => 'Kangelu $1 {{PLURAL:$1|tripalu}}',
'shown-title'                      => 'Pengelün $1 {{PLURAL:$1|Tripalu}} wülngiñ mew',
'viewprevnext'                     => 'Pen ($1 {{int:pipe-separator}} $2) ($3).',
'searchmenu-exists'                => "'''Müley kiñe wülngiñ «[[:$1]]» pingelu feychi wiki mew'''",
'searchmenu-new'                   => "'''¡Llitun pakina «[[:$1]]» tüfachi wiki mew!'''",
'searchhelp-url'                   => 'Help:Trokiñdungu',
'searchprofile-articles'           => 'Trokiñdungu wülngiñ',
'searchprofile-project'            => 'Kellu wülngiñ ka Deumandungu wülngiñ',
'searchprofile-images'             => 'Fill dungu (adentun, dungun, fidew)',
'searchprofile-everything'         => 'Kom',
'searchprofile-advanced'           => 'Doy amul',
'searchprofile-articles-tooltip'   => 'kintun $1 mew',
'searchprofile-project-tooltip'    => 'Kintun $1 mew',
'searchprofile-images-tooltip'     => 'Kintun eltukawün',
'searchprofile-everything-tooltip' => 'Kintun kom trokiñdungu (ka konkülechi nütramkawe)',
'searchprofile-advanced-tooltip'   => 'Kintun Wünezulliñ üytun ñi wellin',
'search-result-size'               => "$1 ({{PLURAL:$2 n'emvl}})",
'search-result-category-size'      => '{{PLURAL:$1 koneltulu}} ({{PLURAL:$2 minche trokiñ}}, {{PLURAL:$3 eltukawün}})',
'search-redirect'                  => '(wüñongünengey $1 mew)',
'search-section'                   => '(katrüntuku $1)',
'search-suggest'                   => 'Tüfa ta küpa chumpimi: $1',
'search-interwiki-more'            => '(Doy)',
'searchrelated'                    => 'koneltuyelelu',
'searchall'                        => 'kom',
'showingresultsheader'             => "{{PLURAL:$5|'''$1''' ñi tripalu '''$3''' mew|'''$1-$2''' ñi tripalu '''$3''' mew}} '''$4''' ngealu",
'search-nonefound'                 => 'Tripalu dungu falilay chumngechi kintuael.',
'powersearch'                      => 'Kintun',
'powersearch-field'                => 'Kintun',

# Preferences page
'mypreferences'           => 'Tami dullin',
'prefs-edits'             => 'Rakin Wirin:',
'prefsnologin'            => 'Mülelay Konün',
'skin-preview'            => 'Pen chum müley',
'prefs-editing'           => 'Wirin',
'searchresultshead'       => 'Kintun',
'timezoneregion-africa'   => 'Afrika',
'timezoneregion-america'  => 'Amerika',
'timezoneregion-arctic'   => 'Artiku',
'timezoneregion-asia'     => 'Asia',
'timezoneregion-europe'   => 'Ewropa',
'youremail'               => 'Werküwe:',
'username'                => 'Üy kellufe:',
'yourrealname'            => 'Mupiñ üy:',
'yourlanguage'            => 'Cezugun:',
'gender-male'             => 'Wentru',
'gender-female'           => 'Domo',
'prefs-help-email'        => 'Mülelay mi eluael feychi werküwe, welu zuamafimi wüñoeltuael tami nülawe ngoyünienngelu.',
'prefs-help-email-others' => 'Müley kiñe lasun tami wülngiñ kam nütramkawe wülngiñ mew amulam werküwe mew. Tami werküwe ñi üy pengelngelay.',

# User rights
'userrights-user-editname' => 'Wirin kiñe üy kellufe mew:',

# Groups
'group'       => 'Kisuwen:',
'group-user'  => 'Pu kellufe',
'group-sysop' => 'Pu ngünefe',
'group-all'   => '(kom pu che)',

'group-user-member' => '{{GENDER:$1|Kellufe}}',

'grouppage-user' => '{{ns:project}}: Pu kellufe',

# Rights
'right-edit'          => 'Wirin pakina',
'right-createpage'    => 'Llitun pakina (nütramkayam pakinanongelu)',
'right-createtalk'    => 'Llitun nütramkayam pakina',
'right-move'          => 'Nengümün pakina',
'right-delete'        => 'Ñamümün pakina',
'right-browsearchive' => 'kintun pakina ñamümüngelu',
'right-undelete'      => 'Wüñoñamümün kiñe pakina',

# User rights log
'rightsnone' => 'chemnorume',

# Associated actions - in the sentence "You do not have permission to X"
'action-read'          => 'chillkatun tüfachi pakina',
'action-edit'          => 'wirin tüfachi pakina',
'action-createpage'    => 'llitun pakina',
'action-createtalk'    => 'llitun nütramkawe pakina',
'action-move'          => 'Nengümün tüfachi pakina',
'action-delete'        => 'Ñamümün tüfachi pakina',
'action-browsearchive' => 'Kintun ñamün pakina',
'action-undelete'      => 'Namümlay tüfachi pakina',

# Recent changes
'nchanges'                          => '{{PLURAL:$1|kalekünuy|kalekünuy}} $1',
'recentchanges'                     => 'Weke kalekünun',
'recentchanges-legend'              => 'Weke kalekünun ñi dullin',
'recentchangestext'                 => 'Inayafin doy weke kalekünun tüfa mew.',
'recentchanges-feed-description'    => 'Inayafin doy weke kalekünun wiki ñi amuldungu mew',
'recentchanges-label-newpage'       => 'Tüfachi wirin dewmakey kiñe we wülngiñ.',
'recentchanges-label-minor'         => 'Tüfachi ta kiñe pichi wirin',
'recentchanges-label-bot'           => 'Kiñe kizuamukelu küzauwe dewmay tüfachi wirin.',
'recentchanges-label-unpatrolled'   => 'Pukintulelay tüfachi wirin.',
'rcnote'                            => 'Nagpüle {{PLURAL:müley $1 kalekünun}}, rupalu {{PLURAL:$2 antü}}, $5, $4.',
'rcnotefrom'                        => "Nagpüle müley fill wirin tuwülu '''$2''' mew (tripalu '''$1''' mew).",
'rclistfrom'                        => 'Adkintun weke kalekünun amuamugelu $1',
'rcshowhideminor'                   => '$1 pichi wirin',
'rcshowhidebots'                    => '$1 kiduamukelu küdauwe',
'rcshowhideliu'                     => '$1 konkülelu kellufe',
'rcshowhideanons'                   => '$1 üyngenulu kellufe',
'rcshowhidepatr'                    => '$1 pukintulu kalekünun',
'rcshowhidemine'                    => '$1 tañi wirin',
'rclinks'                           => 'Adkintun doy we $1 kalekünun, tunte $2 antü mew<br />$3',
'diff'                              => 'Kalelu',
'hist'                              => 'rupañ',
'hide'                              => 'Ellkan',
'show'                              => 'Pengelün',
'minoreditletter'                   => 'p',
'newpageletter'                     => 'W',
'boteditletter'                     => 'küdauwe',
'number_of_watching_users_pageview' => '[$1 {{PLURAL:$1|Kellufe|Kellufe}} wiñamüy]',
'rc-enhanced-expand'                => 'Adkintun doy dungu (JavaScript duamyengey)',
'rc-enhanced-hide'                  => 'Ellkan doy dungu',

# Recent changes linked
'recentchangeslinked'          => 'Koneltuyelelu kalekünulu wirin',
'recentchangeslinked-toolbox'  => 'Koneltuyelelu kalekünulu wirin',
'recentchangeslinked-title'    => 'Koneltuyelelu kalekünun tuwküleyelu "$1"',
'recentchangeslinked-noresult' => 'Nülkükawlelu wülngiñ kalekünulay.',
'recentchangeslinked-summary'  => "Tüfachi wif niey pu wülngiñ kalekünulu ka nülkükawlelu kiñe feypingechi wülngiñ (kam nülkükawlelu feypingechi trokiñ).
[[Special:Watchlist|Tami llaytun wif]] ñi pu wülngiñ '''kurükünuley'''.",
'recentchangeslinked-page'     => 'Wülngiñ ñi üy:',
'recentchangeslinked-to'       => 'Adkintun weke kalekünun pengelafulu feypilel wülngiñ.',

# Upload
'upload'          => 'Püramün eltukawün',
'uploadnologin'   => 'Petu konlaymi',
'uploadlogpage'   => 'Püramülu eltukawün ñi wirintukun',
'filedesc'        => 'Pichi trokiñündungu',
'uploadedimage'   => 'Püramüngey "[[$1]]"',
'watchthisupload' => 'Llaytun tüfachi eltukawün',

'license'        => 'Dungunentuwün:',
'license-header' => 'Dungunentuwün',
'nolicense'      => 'Chemnorume dullinnongey',

# Special:ListFiles
'listfiles_search_for' => 'Kintun üy ad:',
'listfiles_name'       => 'Üy',
'listfiles_user'       => 'Kellufe',

# File description page
'file-anchor-link'       => 'Eltukawün',
'filehist'               => 'Eltukawün ñi rupañmael',
'filehist-help'          => 'Pütafün antü/ora adkintuam feychi eltukawün.',
'filehist-deleteall'     => 'kom ñamümün',
'filehist-deleteone'     => 'ñamümün tüfa',
'filehist-revert'        => 'wüñoeltun',
'filehist-current'       => 'Fantepu',
'filehist-datetime'      => 'Antü/Ora',
'filehist-thumb'         => 'Pichi pegel',
'filehist-thumbtext'     => 'Tripay tüfachi pichi pegel $1 mew',
'filehist-user'          => 'Kellufe',
'filehist-dimensions'    => 'Tunten ngen',
'filehist-comment'       => 'Ngütramkawün',
'imagelinks'             => 'Eltukawün ñi pünelelu',
'linkstoimage'           => 'Tüfachi {{PLURAL:$1|wülngiñ nülkükawley|$1 wülngiñ nülkükawleyngün}} tüfachi eltukawün:',
'nolinkstoimage'         => 'Kiñe wülngiñ no rume nülkükawlelay tüfachi eltukawün',
'sharedupload-desc-here' => 'Tüfachi eltukawün küpay $1 mew. Pepipünengey kake deumandungu.
Fey ñi chumngen mülelu ($2 fey ñi chumngen wülngiñ) pengeli tüfa mew.',

# File deletion
'filedelete'                 => '$1 ñamümün',
'filedelete-intro'           => "Ñamümmekeymi '''[[Media:$1|$1]]'''.",
'filedelete-submit'          => 'Ñamümün',
'filedelete-success'         => "'''$1''' ñamümngey.",
'filedelete-edit-reasonlist' => 'Wirin dungu ñamümgün mew',

# MIME search
'download' => 'nakvmpafipe',

# Unused templates
'unusedtemplateswlh' => 'Kake lasun',

# Random page
'randompage' => 'Tuchi wülngiñ rume',

# Statistics
'statistics'       => 'Chuntelen',
'statistics-pages' => 'Pakina',

'disambiguationspage' => 'Template:Kiñeduamngelu dungu',

'brokenredirects-edit'   => 'pepikan',
'brokenredirects-delete' => 'ñamümün',

'withoutinterwiki-submit' => 'Pegelpe',

# Miscellaneous special pages
'nbytes'            => '$1 {{PLURAL:$1 byte}}',
'nmembers'          => '$1 {{PLURAL:$1|koneltulu}}',
'nviews'            => '$1 {{PLURAL:$1|pen|pen}}',
'prefixindex'       => 'Kom wülngiñ engu wüne konkülelu nemül',
'shortpages'        => 'Pichi pakina',
'usercreated'       => '{{GENDER:$3|Dewmangey}} $1, $2 mew',
'newpages'          => 'Weke wülngiñ',
'newpages-username' => 'Kellufe ñi üy',
'move'              => 'Wiñamün',
'movethispage'      => 'Nengümün tüfachi pakina',
'pager-newer-n'     => '{{PLURAL: Kangelu $1}}',
'pager-older-n'     => '{{PLURAL: Rupachi $1}}',

# Book sources
'booksources'               => 'Lifüru ñi chew küpan',
'booksources-search-legend' => 'Kintun lifüru ñi chew küpan',
'booksources-go'            => 'Amun',

# Special:Log
'specialloguserlabel'  => 'Kellufe:',
'speciallogtitlelabel' => 'Chew ñi amuael (Üy):',
'log'                  => 'Wirintukun',

# Special:AllPages
'allpages'       => 'Fill wülngiñ',
'alphaindexline' => '$1, $2 mew',
'allarticles'    => 'Fill wülngiñ',
'allpagesnext'   => 'Inan',
'allpagessubmit' => 'Pengelün',

# Special:Categories
'categories' => 'Fill trokiñ',

# Special:LinkSearch
'linksearch-ok'   => 'Kintun',
'linksearch-line' => '$1 nülkükawlelu $2 mew',

# Special:ListUsers
'listusers-submit' => 'Pengelün',

# Special:Log/newusers
'newuserlogpage' => 'We kellufe ñi wirintukun',

# Special:ListGroupRights
'listgrouprights-members' => '(koneltulu kellufe ñi wif)',

# E-mail user
'emailuser'    => 'Amulün werküwe tüfachi kellufe',
'emailsubject' => 'Dungu',
'emailmessage' => 'Dungu',
'emailsend'    => 'Werkün',

# Watchlist
'watchlist'         => 'Tañi llaytun wif',
'mywatchlist'       => 'Tañi llaytun wif',
'watchlistfor2'     => '$1 ($2)',
'watchnologin'      => 'Petu konlaymi',
'watch'             => 'Llaytun',
'watchthispage'     => 'Llaytun tüfachi pakina',
'unwatch'           => 'Llaytuwelan',
'unwatchthispage'   => 'Llaytuwelan',
'notanarticle'      => 'Trokiñdungu wülngiñ nu',
'watchlist-details' => '{{PLURAL:$1|$1 wülngiñ}} tami llaytun wif mew. Inantukulay nütramkawün ñi wülngiñ.',
'wlshowlast'        => 'Pengelün kalekünun rupalu $1 ora, $2 antü $3',
'watchlist-options' => 'Llaytun wif ñi dullin',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Llaytumekey...',
'unwatching' => 'Llaytumekewelay...',

'enotif_newpagetext'           => 'Tüfachi ta we pakina',
'enotif_impersonal_salutation' => '{{SITENAME}} kellufe',
'created'                      => 'Llituy',

# Delete
'deletepage'            => 'Ñamümün tüfachi pakina',
'exblank'               => 'pakina wellingey',
'delete-confirm'        => 'Ñamümüngelu "$1"',
'delete-legend'         => 'Ñamümün',
'actioncomplete'        => 'Wechuley chi femün',
'actionfailed'          => 'Wedalkay chi femün.',
'dellogpage'            => 'Liftungepelu wülngiñ ñi wirintukun',
'deletereasonotherlist' => 'Kake dungu',

# Rollback
'rollbacklink' => 'Wüñoeltun',

# Protect
'protectlogpage'          => 'Nürüfkünulu wülngiñ ñi wirintukun',
'protectedarticle'        => 'nürüfkünuy "[[$1]]"',
'prot_1movedto2'          => '[[$1]] wiñamngey [[$2]] püle',
'protectexpiry'           => 'Afi:',
'protect-level-sysop'     => 'Pu ngünefe müṯen',
'protect-summary-cascade' => 'Trayengko',
'protect-expiry-options'  => '1 ora:1 hour,1 aṉtü:1 day,1 semana:1 week,2 semanas:2 weeks,1 küyeṉ:1 month,3 küyeṉ:3 months,6 küyeṉ:6 months,1 tripantu:1 year,Rumel:infinite',

# Restrictions (nouns)
'restriction-edit'   => 'Pepiwelukay',
'restriction-move'   => 'Pepiwiñami',
'restriction-create' => 'Llitun',

# Undelete
'viewdeletedpage'           => 'Pen pakina ñamümüngelu',
'undeletelink'              => 'pen/kümeeltun',
'undeleteviewlink'          => 'Pen',
'undelete-search-box'       => 'Kintun ñamümüngelu pakina',
'undelete-search-submit'    => 'Kintun',
'undelete-show-file-submit' => 'May',

# Namespace form on various pages
'namespace'      => 'Üytun ñi wellin:',
'invert'         => 'Welulün dullin',
'blanknamespace' => '(Ñidol)',

# Contributions
'contributions'       => 'Kellufe ñi wirin',
'contributions-title' => 'kellufe $1 ñi wirin',
'mycontris'           => 'Tañi kellukontun',
'contribsub2'         => '$1 ($2)',
'uctop'               => '(wente)',
'month'               => 'Küyeṉ:',
'year'                => 'Tripantu:',

'sp-contributions-newbies'  => 'Pengelün weke kellufe ñi wirin müten',
'sp-contributions-blocklog' => 'Katrüntukun wirintukun',
'sp-contributions-uploads'  => 'Püramngelu',
'sp-contributions-logs'     => 'Wirintukun',
'sp-contributions-talk'     => 'Nütramkan',
'sp-contributions-search'   => 'Kintun fill kellufe ñi wirin',
'sp-contributions-username' => 'IP ñi nütramkawe kam üy kellufe:',
'sp-contributions-toponly'  => 'Adkintun doy weke malün müten',
'sp-contributions-submit'   => 'Kintun',

# What links here
'whatlinkshere'            => 'Lasulu faw püle',
'whatlinkshere-title'      => 'Wülngiñ nülkükawlelu "$1"',
'whatlinkshere-page'       => 'Pakina:',
'linkshere'                => "Tüfachi wülngiñ nülkükawley '''[[:$1]]''':",
'nolinkshere'              => "Chem wülngiñ no rume nülkükawlelu '''[[:$1]]'''.",
'isredirect'               => 'wüñongünen wülngiñ',
'istemplate'               => 'yomtukudungu',
'isimage'                  => 'Adentun lasun',
'whatlinkshere-prev'       => '{{PLURAL:$1|Pen chum müley|Pen chum müluey $1}}',
'whatlinkshere-next'       => '{{PLURAL:$1|kangelu $1}}',
'whatlinkshere-links'      => '← lasun',
'whatlinkshere-hideredirs' => '$1 wüñongünenielu',
'whatlinkshere-hidetrans'  => '$1 yomtukudungu',
'whatlinkshere-hidelinks'  => '$1 lasun',
'whatlinkshere-hideimages' => '$1 nülkükawley adentun',
'whatlinkshere-filters'    => 'Chaytuwe',

# Block/unblock
'ipbexpiry'                  => 'Afi',
'ipbreason'                  => 'Dungu:',
'ipbreasonotherlist'         => 'Kake dungu:',
'ipboptions'                 => '2 ora:2 hours,1 aṉtü:1 day,3 aṉtü:3 days,1 semana:1 week,2 semana:2 weeks,1 küyeṉ:1 month,3 küyeṉ:3 months,6 küyeṉ:6 months,1 tripantu:1 year,rumel:infinite',
'ipbotheroption'             => 'Kakelu',
'ipblocklist'                => 'Katrütulelu kellufe',
'ipblocklist-submit'         => 'Kintun',
'expiringblock'              => 'afi $1 - $2',
'blocklink'                  => 'Katrütukun',
'unblocklink'                => 'katrüntukulan',
'change-blocklink'           => 'kalekünun katrüntukun',
'contribslink'               => 'kellukontun',
'blocklogpage'               => 'Katrüntukun ñi wirintukun',
'blocklogentry'              => 'Katrüntukufi [[$1]] $2 antü/ora mew, $3',
'block-log-flags-nocreate'   => 'Pepi dewmangelay konün',
'block-log-flags-hiddenname' => 'Üy kellufe ellkan',
'proxyblocksuccess'          => 'Dewmangey.',

# Move page
'move-page'               => 'Nengümün $1',
'move-page-legend'        => 'Nengümün wülngiñ',
'movearticle'             => 'Nengümün wülngiñ',
'movenologin'             => 'Konlaymi',
'newtitle'                => 'We üy püle',
'move-watch'              => 'Llaytun tüfachi pakina',
'movepagebtn'             => 'Nengümün pakina',
'movedto'                 => 'Nengümün',
'movelogpage'             => 'Nengümün wirintukun',
'revertmove'              => 'wüñoeltun',
'delete_and_move'         => 'Ñamümün ka nengümün',
'delete_and_move_confirm' => 'May, ñamümün pakina',

# Export
'export' => 'Wiñamün pakina',

# Namespace 8 related
'allmessagesname'      => 'Üy',
'allmessagesdefault'   => 'Wirin wüne dullin reke',
'allmessages-language' => 'Cezugun:',

# Thumbnails
'thumbnail-more'  => 'Rume fütra',
'thumbnail_error' => 'Welulkan deumayam pichi pegel adentun: $1',

# Tooltip help for the actions
'tooltip-pt-userpage'             => 'Tami wülngiñ',
'tooltip-pt-mytalk'               => 'Tami nütramkawe',
'tooltip-pt-preferences'          => 'Tami dullin',
'tooltip-pt-watchlist'            => 'Mi llaytulu wülngiñ ñi wif',
'tooltip-pt-mycontris'            => 'Tami kellukontun ñi wif',
'tooltip-pt-login'                => 'Feypingey tami Konküleal, welu mülelay mi femael',
'tooltip-pt-logout'               => 'Tripan',
'tooltip-ca-talk'                 => 'Ngütramkawün wülgiñ ñi zungu mew',
'tooltip-ca-edit'                 => 'Kümeelaymi tüfachi wülngiñ. Elmekeaymi wüne pen petu eltukawam.',
'tooltip-ca-addsection'           => 'Llitun we trokiñ',
'tooltip-ca-viewsource'           => 'Nürüfkünungey tüfachi wülngiñ. Kimaymi chew küpan chi wirin',
'tooltip-ca-history'              => 'Tüfachi wülngiñ ñi rupachi malün',
'tooltip-ca-protect'              => 'Nürüfkünun tüfachi wülngiñ',
'tooltip-ca-delete'               => 'Liftun tüfachi wülngiñ',
'tooltip-ca-move'                 => 'Nengümün tüfachi wülngiñ',
'tooltip-ca-watch'                => 'Püñamtun tüfachi wülngiñ tami llaytun wif mew',
'tooltip-ca-unwatch'              => 'Püñamtun tüfachi wülngiñ tami llaytun wif mew',
'tooltip-search'                  => 'Kintun {{SITENAME}} mew',
'tooltip-search-go'               => 'Amun wülngiñ ñi rüf üy, müleyele.',
'tooltip-search-fulltext'         => 'Kintun tüfachi dungu fill wülngiñ mew',
'tooltip-p-logo'                  => 'Amulün feychi wüne wülngiñ',
'tooltip-n-mainpage'              => 'Amulün ñidol wülngiñ mew',
'tooltip-n-mainpage-description'  => 'Tripan nidol wülgiñ mew',
'tooltip-n-portal'                => 'Chumngen ñi deumandungu, chem pepi dewmaymi, chew müley dungu',
'tooltip-n-currentevents'         => 'Fantepu chemkün ñi dungu',
'tooltip-n-recentchanges'         => 'Weke kalekünun ñi wif, wiki mew',
'tooltip-n-randompage'            => 'Amulün tuchi wülngiñ rume',
'tooltip-n-help'                  => 'Chew adümngeam',
'tooltip-t-whatlinkshere'         => 'Kom wiki ñi wülgiñ nülkükawlelu tüfa mew',
'tooltip-t-recentchangeslinked'   => 'Weke kalekünun kake wülngiñ nülkükawlu tüfa mew',
'tooltip-feed-atom'               => 'Atom ñi amuldungu tüfachi wülngiñ ngealu',
'tooltip-t-contributions'         => 'Tüfachi kellufe ñi wirin ñi wif',
'tooltip-t-emailuser'             => 'Amulün werküwe tüfachi kellufe',
'tooltip-t-upload'                => 'Püramün adentun kam fill dungu eltukawün',
'tooltip-t-specialpages'          => 'Kom wichuke wülngiñ ñi wif',
'tooltip-t-print'                 => 'Tripan tüfachi wülngiñ nentuwirinael',
'tooltip-t-permalink'             => 'Mülekalelu lasun nülkükawley tüfachi wülngiñ ñi malün',
'tooltip-ca-nstab-main'           => 'Adkintun trokiñdungu wülngiñ',
'tooltip-ca-nstab-user'           => 'Adkintun kellufe ñi wülngiñ',
'tooltip-ca-nstab-special'        => 'Tüfa ta wichu wülngiñ. Pepi wiritulaymi tüfa mew.',
'tooltip-ca-nstab-project'        => 'Adkintun deumandungu wülngiñ',
'tooltip-ca-nstab-image'          => 'Pen adentun ñi wülngiñ',
'tooltip-ca-nstab-template'       => 'Adkintun feychi adtükupeyüm',
'tooltip-ca-nstab-help'           => 'Pen kellupakina',
'tooltip-ca-nstab-category'       => 'Adkintun trokiñ wülgiñ',
'tooltip-minoredit'               => 'Üytukun kiñe pichi wirin reke',
'tooltip-save'                    => 'Eltukawün tami kalekünun',
'tooltip-preview'                 => 'Wüne pen tüfa petu eltukawam!',
'tooltip-diff'                    => 'Adkintun tami kalekünun feychi wirin mew',
'tooltip-compareselectedversions' => 'Trürümün epu dullinngelu malün ta tüfachi wülngiñ',
'tooltip-watch'                   => 'Püñamtun tüfachi wülngiñ tami llaytun wif mew',
'tooltip-rollback'                => '"Wüñoeltun " ta wüñoeltun wirin dewmalu rupalu kellufe tüfachi wülngiñ mew, kiñe pütaf müten.',
'tooltip-undo'                    => '"wüñoeltun" tüfachi wirin ka nülan wirin ñi wülngiñ wüne pen petu eltukawam. Pepi püñamtuymi kiñe rakiduam pichi trokiñündungu mew.',
'tooltip-summary'                 => 'Tukuymi pichi trokiñünzugu',

# Attribution
'siteuser'  => 'Kellufe $1 {{SITENAME}}',
'others'    => 'fill',
'siteusers' => '{{PLURAL:$2|Kellufe|Kellufe}} $1 {{SITENAME}}',

# Browsing diffs
'previousdiff' => '← Füta wirin',
'nextdiff'     => 'We wirin →',

# Media information
'file-info-size' => '$1 × $2 adentun piküsel, eltukawün ñi tunte ngen: $3, MIME ñi chumngen: $4',
'file-nohires'   => 'Pepiduamngefalay chum pengeam.',
'svg-long-desc'  => 'SVG eltukawe, pingey $1 × $2 adentun piküsel, eltukawün ñi tunte ngen: $3',
'show-big-image' => 'Rüf chum pengeam',

# Special:NewFiles
'ilsubmit' => 'Kintu',

# Video information, used by Language::formatTimePeriod() to format lengths in the above messages
'hours-abbrev' => '$1o',

# Bad image list
'bad_image_list' => 'Feychi chumkünuwe ta femngechi:

Wif chemkün (llitulu * mew) kimngey müten.
Feychi wünen lasun wif mew müleay ñi nülkükawael weda eltukawün.
Chem lason rume rupalu feychi wif mew ta feyke. Famngechireke, wülngiñ püneley feychi eltukawün.',

# Metadata
'metadata'        => 'Doy dungu',
'metadata-help'   => 'Tüfachi eltukawün niey doy dungu, tañi inantukulu feychi Diqital kamara kam eskaner. Kalekünule ñi rüf chumkülen, kiñeke chemkün ñami.',
'metadata-fields' => 'Tüfachi adnentun ñi doy dungu tukungeay feychi adentun ñi wülngiñ, nülanmeu feychi trafla. 
Ka dungu ellkangeay wünedullin reke.
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength
* artist
* copyright
* imagedescription
* gpslatitude
* gpslongitude
* gpsaltitude',

# EXIF tags
'exif-artist'              => 'Che llitun mew',
'exif-exposuretime-format' => '$1 sek ($2)',

'exif-exposureprogram-1' => 'Chillka kellu',

'exif-meteringmode-0'   => 'Kimnoelchi',
'exif-meteringmode-255' => 'Kakelu',

'exif-lightsource-0' => 'Kimnoelchi',

'exif-gaincontrol-0' => 'Chemnorume',

'exif-contrast-2' => 'Yafü',

'exif-sharpness-2' => 'Yafü',

'exif-subjectdistancerange-0' => 'Kimnoelchi',

# External editor support
'edit-externally'      => 'Kümeelün tüfachi eltukawün wekun küdauwe mew',
'edit-externally-help' => '(Pen feychi [//www.mediawiki.org/wiki/Manual:External_editors adtukünun chumngechi pünengeael]  doy dungungeam)',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'kom',
'namespacesall' => 'kom',
'monthsall'     => '(kom)',
'limitall'      => 'Kom',

# action=purge
'confirm_purge_button' => 'Feley may',

# Multipage image navigation
'imgmultigo'   => 'Amun!',
'imgmultigoto' => 'Amun pakina $1 mew',

# Table pager
'table_pager_limit_submit' => 'Amun',

# Size units
'size-bytes'     => '$1 b',
'size-kilobytes' => '$1 Kb',
'size-megabytes' => '$1 Mb',
'size-gigabytes' => '$1 Gb',

# Watchlist editing tools
'watchlisttools-view' => 'Adkintun kalekünun',
'watchlisttools-edit' => 'Pengelün ka kalekünun llaytun wif',
'watchlisttools-raw'  => 'kümeelün llaytulu wülngiñ rüfngen mew',

# Core parser functions
'duplicate-defaultsort' => '\'\'\'Ngüneltun:\'\'\' Wünezullin ñi kümeelgen lonkolelu "$2" nentutuy rupalu wünezullin ñi kümeelgen lonkolelu "$1".',

# Special:Version
'version-other' => 'Kakelu',

# Special:FileDuplicateSearch
'fileduplicatesearch-submit' => 'Kintun',

# Special:SpecialPages
'specialpages'                 => 'Wichuke wülngiñ',
'specialpages-group-login'     => 'Konün',
'specialpages-group-pagetools' => 'Küsawkawe pakina mew',

# Special:BlankPage
'blankpage' => 'welli pakina',

# External image whitelist
'external_image_whitelist' => ' #Kakünukilnge tüfachi wirin<pre>
#Tukunge kalekenulu pin (fey konküley // mew müten) nagpüle
#Fey ta wekun adnentun (hotlinked) ñi URL
#Pengelngeay küme URL adentun reke, femnuale pengelneay adentun ñi lasun.
#Wif tuwüli # ta ngütramkawün reke
#Kimfal-lay fütrake wirin ka pichike wirin

#Tukunge kom regex nemül wente tüfachi wirin mew. Kakünukilnge tüfachi wirin</pre>',

# Special:Tags
'tag-filter' => '[[Special:Tags|Tag]] ñi chaytuwe:',
'tags-edit'  => 'Wirin',

# HTML forms
'htmlform-selectorother-other' => 'Kakelu',

);
